SimpodHttpServer class
Constructors
- SimpodHttpServer({int port = 5210, String host = "127.0.0.1", required String accessToken})
Properties
- accessToken → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- host → String
-
final
- port → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
start(
) → Future< void> -
staticHandler(
) → Future< Handler> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited